# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class TypeProtectionPolicyEnum(object):

    """Implementation of the 'TypeProtectionPolicy' enum.
    Specifies the type of the protection policy. 'kRegular' means a regular
    Protection Policy. 'kRPO' means an RPO Protection Policy.


    Attributes:
        KREGULAR: TODO: type description here.
        KRPO: TODO: type description here.

    """

    KREGULAR = 'kRegular'

    KRPO = 'kRPO'
